@@ -1,7 +1,7 @@
 import glob
 from os.path import basename, dirname, isfile, join
 
-version = "0.0.1"
+version = "0.0.22"
 __author__ = "Stefan Welcker"
 __copyright__ = "Copyright 2022, U2D.ai"
 __license__ = "MIT"
@@ -12,6 +12,4 @@ __status__ = "Beta"
 __url__ = "https://github.com/u2d-ai/msaBase"
 
 modules = glob.glob(join(dirname(__file__), "*.py"))
-__all__ = [
-    basename(f)[:-3] for f in modules if isfile(f) and not f.endswith("__init__.py")
-]
+__all__ = [basename(f)[:-3] for f in modules if isfile(f) and not f.endswith("__init__.py")]
