@@ -7,38 +7,32 @@ Initialize with a MSAServiceDefintion Instance to control the features and funct
 import os
 from asyncio import Task
 from datetime import datetime
-from typing import List, Type, Union
+from typing import Any, Dict, List, Optional, Type, Union
 
+from dapr.clients import DaprClient
 from fastapi import FastAPI, HTTPException
 from fastapi.encoders import jsonable_encoder
 from fastapi.exception_handlers import http_exception_handler
 from fastapi.exceptions import RequestValidationError
 from fastapi.responses import ORJSONResponse
 from loguru import logger as logger_gruru
+from msaBase.config import MSAServiceDefinition, MSAServiceStatus
+from msaBase.errorhandling import getMSABaseExceptionHandler
+from msaBase.logger import init_logging
+from msaBase.models.functionality import FunctionalityTypes
+from msaBase.models.middlewares import MiddlewareTypes
+from msaBase.models.sysinfo import MSASystemGPUInfo, MSASystemInfo
+from msaBase.sysinfo import get_sysgpuinfo, get_sysinfo
 from msaDocModels.health import MSAHealthDefinition, MSAHealthMessage
-from msaDocModels.scheduler import (
-    MSASchedulerStatus,
-    MSASchedulerTaskDetail,
-    MSASchedulerTaskStatus,
-)
+from msaDocModels.openapi import MSAOpenAPIInfo
+from msaDocModels.scheduler import MSASchedulerStatus, MSASchedulerTaskDetail, MSASchedulerTaskStatus
 from msaDocModels.sdu import SDUVersion
-from msaSDK.models.openapi import MSAOpenAPIInfo
-from msaSDK.models.service import MSAServiceStatus
-from sqlmodel import SQLModel
 from starlette import status
 from starlette.exceptions import HTTPException as StarletteHTTPException
 from starlette.requests import Request
 from starlette.responses import HTMLResponse, JSONResponse, Response
 from starlette_context import plugins
 
-from msaBase.config import MSAServiceDefinition
-from msaBase.errorhandling import getMSABaseExceptionHandler
-from msaBase.logger import init_logging
-from msaBase.models.functionality import FunctionalityTypes
-from msaBase.models.middlewares import MiddlewareTypes
-from msaBase.models.sysinfo import MSASystemInfo
-from msaBase.sysinfo import get_sysinfo
-
 
 def getSecretKey() -> str:
     """
@@ -86,7 +80,7 @@ def getSecretKeyCSRF() -> str:
 
 
 class MSAApp(FastAPI):
-    """Creates an application msaSDK instance.
+    """Creates an application msaBase instance.
 
     Note:
         As with FastApi the MSAApp provides two events:
@@ -107,9 +101,6 @@ class MSAApp(FastAPI):
         settings: MSAServiceDefinition settings instance.
         healthdefinition: MSAHealthDefinition settings.healthdefinition
         limiter: Limiter = None
-        db_engine: AsyncEngine = Db Engine instance
-        sql_models: List[SQLModel] = sql_models
-        sql_cruds: List[MSASQLModelCrud] = []
         scheduler: MSAScheduler = None
         scheduler_task: The Task instance that runs the Scheduler in the Background
         ROOTPATH: str os.path.join(os.path.dirname(__file__))
@@ -119,8 +110,15 @@ class MSAApp(FastAPI):
     def __init__(
         self,
         settings: MSAServiceDefinition,
-        sql_models: List[SQLModel] = None,
         auto_mount_site: bool = True,
+        title: str = "FastAPI",
+        description: str = "",
+        version: str = "0.1.0",
+        openapi_url: Optional[str] = "/openapi.json",
+        openapi_tags: Optional[List[Dict[str, Any]]] = None,
+        terms_of_service: Optional[str] = None,
+        contact: Optional[Dict[str, Union[str, Any]]] = None,
+        license_info: Optional[Dict[str, Union[str, Any]]] = None,
         *args,
         **kwargs,
     ) -> None:
@@ -128,19 +126,20 @@ class MSAApp(FastAPI):
         super().__init__(*args, **settings.fastapi_kwargs)
 
         self.logger = logger_gruru
-        init_logging()
-
+        self.fastApi = FastAPI
+        self.title = title
+        self.description = description
+        self.version = version
+        self.openapi_url = openapi_url
         self.auto_mount_site: bool = auto_mount_site
         self.settings = settings
-        self.SDUVersion = SDUVersion(
-            version=self.settings.version, creation_date=datetime.utcnow().isoformat()
-        )
+        self.SDUVersion = SDUVersion(version=self.settings.version, creation_date=datetime.utcnow().isoformat())
+        self.license_info = license_info
+        self.contact = contact
+        self.terms_of_service = terms_of_service
+        self.openapi_tags = openapi_tags
         self.healthdefinition: MSAHealthDefinition = self.settings.healthdefinition
         self.limiter: "Limiter" = None
-        self.sqlite_db_engine: "AsyncEngine" = None
-        self.json_db_engine: "TinyDB" = None
-        self.sql_models: List[SQLModel] = sql_models
-        self.sql_cruds: List["MSASQLModelCrud"] = []
         self.background_scheduler: "BackgroundScheduler" = None
         self.asyncio_scheduler: "AsyncIOScheduler" = None
         self.site = None
@@ -149,50 +148,47 @@ class MSAApp(FastAPI):
         self.abstract_fs: "MSAFilesystem" = None
         self.fs: "FS" = None
         self.healthcheck: "health.MSAHealthCheck" = None
+        self.logger.info_pub = self.logger_info
 
         init_logging()
         self.add_middlewares()
         self.add_functionality()
-
         self.logger.info("Events - Add Internal Handlers")
         self.add_event_handler("shutdown", self.shutdown_event)
         self.add_event_handler("startup", self.startup_event)
 
+    def logger_info(self, message: str, topic_name: str = ""):
+        if topic_name:
+            with DaprClient() as client:
+                client.publish_event(
+                    pubsub_name="spkpubsub",
+                    topic_name=topic_name,
+                    data=message,
+                    data_content_type="application/json",
+                )
+        self.logger.info(message)
+
     async def extend_startup_event(self) -> None:
         """You can extend the main shutdown"""
 
     async def startup_event(self) -> None:
         """Internal Startup Event Handler"""
-        self.logger.info("msaSDK Internal Startup MSAUIEvent")
+        self.logger.info("msaBase Internal Startup MSAUIEvent")
         await self.extend_startup_event()
 
-        if self.settings.sqlite_db:
-            async with self.sqlite_db_engine.begin() as conn:
-                if self.settings.sqlite_db_meta_drop:
-                    self.logger.info(
-                        "SQLite DB - Drop Meta All: " + self.settings.sqlite_db_url
-                    )
-                    await conn.run_sync(SQLModel.metadata.drop_all)
-                if self.settings.sqlite_db_meta_create:
-                    self.logger.info(
-                        "SQLite DB - Create Meta All: " + self.settings.sqlite_db_url
-                    )
-                    await conn.run_sync(SQLModel.metadata.create_all)
-            await self.sqlite_db_engine.dispose()
-
     async def extend_shutdown_event(self) -> None:
         """You can extend the main shutdown"""
 
     async def shutdown_event(self) -> None:
         """Internal Shutdown event handler"""
-        self.logger.info("msaSDK Internal Shutdown MSAUIEvent")
+        self.logger.info("msaBase Internal Shutdown MSAUIEvent")
         await self.extend_shutdown_event()
 
-        if self.settings.background_scheduler:
+        if self.settings.background_scheduler and self.background_scheduler.get_jobs():
             self.logger.info("Stop Background Scheduler")
             self.background_scheduler.shutdown()
 
-        if self.settings.asyncio_scheduler:
+        if self.settings.asyncio_scheduler and self.asyncio_scheduler.get_jobs():
             self.logger.info("Stop Asyncio Scheduler")
             self.asyncio_scheduler.shutdown()
 
@@ -206,30 +202,16 @@ class MSAApp(FastAPI):
                 self.logger.info("Closing Abstract Filesystem")
                 self.fs.close()
             except Exception as ex:
-                getMSABaseExceptionHandler().handle(
-                    ex, "Error: Closing Abstract Filesystem failed:"
-                )
+                getMSABaseExceptionHandler().handle(ex, "Error: Closing Abstract Filesystem failed:")
 
-        if self.settings.json_db:
-            self.logger.info("JSON DB - Close: " + self.settings.sqlite_db_url)
-            self.json_db_engine.close()
-
-        if self.settings.sqlite_db:
-            self.logger.info(
-                "SQLite DB - Dispose Connections: " + self.settings.sqlite_db_url
-            )
-            await self.sqlite_db_engine.dispose()
-
-    async def init_graphql(self, strawberry_schema) -> None:
+    @staticmethod
+    async def get_system_gpu_info() -> MSASystemGPUInfo:
+        """Get System Nvidia GPU's Info
+        Returns:
+            sysgpuinfo: MSASystemGPUInfo Pydantic Model
         """
-        Internal helper function to initialize the graphql router
-        """
-        if self.settings.graphql:
-            from strawberry.fastapi import GraphQLRouter
-
-            self.graphql_schema = strawberry_schema
-            self.graphql_app = GraphQLRouter(self.graphql_schema, graphiql=True)
-            self.include_router(self.graphql_app, prefix="/graphql", tags=["graphql"])
+        sysgpuinfo = get_sysgpuinfo()
+        return sysgpuinfo
 
     async def get_healthcheck(self, request: Request) -> ORJSONResponse:
         """
@@ -260,10 +242,7 @@ class MSAApp(FastAPI):
         """
         self.logger.info("Called - get_scheduler_status :" + str(request.url))
         sst: MSASchedulerStatus = MSASchedulerStatus()
-        if (
-            not self.settings.background_scheduler
-            or not self.settings.asyncio_scheduler
-        ):
+        if not self.settings.background_scheduler or not self.settings.asyncio_scheduler:
             sst.name = self.settings.name
             sst.message = "Schedulers is disabled!"
 
@@ -308,20 +287,6 @@ class MSAApp(FastAPI):
 
         return sst
 
-    def get_services_definition(self, request: Request) -> MSAServiceDefinition:
-        """
-        Get Service Definition Info
-
-        Args:
-            request: The input http request object
-
-        Returns:
-            settings: MSAServiceDefinition Pydantic Response Model
-
-        """
-        self.logger.info("Called - get_services_definition :" + str(request.url))
-        return self.settings
-
     def get_services_settings(self, request: Request) -> ORJSONResponse:
         """
         Get Service OpenAPI Schema
@@ -377,9 +342,7 @@ class MSAApp(FastAPI):
             }
         )
 
-    async def msa_exception_handler(
-        self, request: Request, exc: HTTPException
-    ) -> Response:
+    async def msa_exception_handler(self, request: Request, exc: HTTPException) -> Response:
         """
         Handles all HTTPExceptions if enabled with HTML Response or forward error if the code is in the exclude settings list.
 
@@ -432,18 +395,14 @@ class MSAApp(FastAPI):
 
         return oai
 
-    async def validation_exception_handler(
-        self, request: Request, exc: RequestValidationError
-    ) -> JSONResponse:
+    async def validation_exception_handler(self, request: Request, exc: RequestValidationError) -> JSONResponse:
         self.logger.error("validation_exception_handler - " + str(exc.errors()))
         return JSONResponse(
             status_code=status.HTTP_422_UNPROCESSABLE_ENTITY,
             content=jsonable_encoder({"detail": exc.errors(), "body": exc.body}),
         )
 
-    async def msa_exception_handler_disabled(
-        self, request: Request, exc: HTTPException
-    ) -> JSONResponse:
+    async def msa_exception_handler_disabled(self, request: Request, exc: HTTPException) -> JSONResponse:
         """
         Handles all HTTPExceptions if Disabled with JSON Response.
 
@@ -537,9 +496,7 @@ class MSAApp(FastAPI):
         }
         return configurator_mappings.get(middleware, self.unknown_middleware)
 
-    def choose_functionality_configurator(
-        self, middleware: FunctionalityTypes
-    ) -> Type[unknown_functionality]:
+    def choose_functionality_configurator(self, middleware: FunctionalityTypes) -> Type[unknown_functionality]:
         """
         Get the configurator by type of Functionality
 
@@ -549,11 +506,7 @@ class MSAApp(FastAPI):
         """
         configurator_mappings = {
             FunctionalityTypes.uvloop: self.configure_event_loop,
-            FunctionalityTypes.json_db: self.configure_json_db,
-            FunctionalityTypes.sqlite_db: self.configure_sqlite_db,
-            FunctionalityTypes.graphql: self.configure_graphql,
             FunctionalityTypes.healthdefinition: self.configure_healthdefinition,
-            FunctionalityTypes.sysrouter: self.configure_sysrouter,
             FunctionalityTypes.servicerouter: self.configure_servicerouter,
             FunctionalityTypes.instrument: self.configure_prometheus_instrument,
             FunctionalityTypes.background_scheduler: self.configure_background_scheduler,
@@ -562,30 +515,6 @@ class MSAApp(FastAPI):
         }
         return configurator_mappings.get(middleware, self.unknown_middleware)
 
-    def configure_json_db(self) -> None:
-        """Create JSON DB"""
-        self.logger.info("JSON DB - Init: " + self.settings.sqlite_db_url)
-        from tinydb import TinyDB
-        from tinydb.storages import MemoryStorage
-
-        if self.settings.json_db_memory_only:
-            self.json_db_engine = TinyDB(
-                self.settings.json_db_url, storage=MemoryStorage
-            )
-        else:
-            self.json_db_engine = TinyDB(
-                self.settings.json_db_url, storage=TinyDB.default_storage_class
-            )
-
-    def configure_graphql(self) -> None:
-        """Init Graphql"""
-        self.logger.info("Init Graphql")
-        from strawberry import schema
-        from strawberry.fastapi import GraphQLRouter
-
-        self.graphql_app: GraphQLRouter = None
-        self.graphql_schema: schema = None
-
     def configure_starception_middleware(self) -> None:
         """Add Middleware Starception"""
         self.logger.info("Add Middleware Starception")
@@ -603,28 +532,17 @@ class MSAApp(FastAPI):
                 tags=["service"],
                 response_model=MSASchedulerStatus,
             )
+        self.add_api_route("/", self.get_sduversion, tags=["service"], response_model=SDUVersion)
+        self.add_api_route("/sysinfo", get_sysinfo, tags=["service"], response_model=MSASystemInfo)
+        self.add_api_route("/sysgpuinfo", self.get_system_gpu_info, tags=["service"], response_model=MSASystemGPUInfo)
+        self.add_api_route("/settings", self.get_services_settings, tags=["service"])
         self.add_api_route(
             "/status",
             self.get_services_status,
             tags=["service"],
             response_model=MSAServiceStatus,
         )
-        self.add_api_route(
-            "/definition",
-            self.get_services_definition,
-            tags=["service"],
-            response_model=MSAServiceDefinition,
-        )
-        self.add_api_route(
-            "/sys_info", get_sysinfo, tags=["service"], response_model=MSASystemInfo
-        )
-        self.add_api_route(
-            "/", self.get_sduversion, tags=["service"], response_model=SDUVersion
-        )
-        self.add_api_route("/settings", self.get_services_settings, tags=["service"])
-        self.add_api_route(
-            "/schema", self.get_services_openapi_schema, tags=["openapi"]
-        )
+        self.add_api_route("/schema", self.get_services_openapi_schema, tags=["openapi"])
         self.add_api_route(
             "/info",
             self.get_services_openapi_info,
@@ -659,50 +577,14 @@ class MSAApp(FastAPI):
         """Add Handler HTTPException"""
         self.logger.info("Add Handler HTTPException")
         exception_handler = (
-            self.msa_exception_handler
-            if self.settings.httpception
-            else self.msa_exception_handler_disabled
+            self.msa_exception_handler if self.settings.httpception else self.msa_exception_handler_disabled
         )
         self.add_exception_handler(StarletteHTTPException, exception_handler)
 
     def configure_validation_handler(self) -> None:
         """Add Handler ValidationError"""
         self.logger.info("Add Handler ValidationError")
-        self.add_exception_handler(
-            RequestValidationError, self.validation_exception_handler
-        )
-
-    def configure_sqlite_db(self) -> None:
-        """Create sqlite db connection and create crud in db by sql_model in Settings"""
-        from sqlalchemy.ext.asyncio import create_async_engine
-        from sqlalchemy.ext.declarative import declarative_base
-        from sqlalchemy.orm import DeclarativeMeta
-
-        self.logger.info("SQLite DB - Init: " + self.settings.sqlite_db_url)
-        self.Base: DeclarativeMeta = declarative_base()
-        self.sqlite_db_engine = create_async_engine(
-            self.settings.sqlite_db_url,
-            echo=self.settings.sqlite_db_debug,
-            future=True,
-        )
-        if self.settings.sqlite_db_crud and self.sql_models:
-            self.configure_db_crud()
-
-    def configure_db_crud(self) -> None:
-        """Register all Models and the crud for them"""
-        if self.settings.sqlite_db_crud and self.sql_models:
-            self.logger.info(
-                "SQLite DB - Register/CRUD SQL Models: " + str(self.sql_models)
-            )
-            from msaCRUD import MSASQLModelCrud
-
-            for model in self.sql_models:
-                new_crud: MSASQLModelCrud = MSASQLModelCrud(
-                    model=model, engine=self.sqlite_db_engine
-                ).register_crud()
-                if self.settings.sqlite_db_crud:
-                    self.include_router(new_crud.router)
-                self.sql_cruds.append(new_crud)
+        self.add_exception_handler(RequestValidationError, self.validation_exception_handler)
 
     def configure_healthdefinition(self) -> None:
         self.logger.info("Init Healthcheck")
@@ -722,13 +604,6 @@ class MSAApp(FastAPI):
             tags=["service"],
         )
 
-    def configure_sysrouter(self) -> None:
-        """Enable Sysrouter"""
-        self.logger.info("Include Sysrouter")
-        from msaSDK.router.system import sys_router
-
-        self.include_router(sys_router)
-
     def configure_abstract_fs(self) -> None:
         """Enable Abstract Filesystem"""
         self.logger.info("Enable Abstract Filesystem")
@@ -821,9 +696,7 @@ class MSAApp(FastAPI):
         self.logger.info("Add Middleware Timing")
         from fastapi_utils.timing import add_timing_middleware
 
-        add_timing_middleware(
-            self, record=self.logger.info, prefix="app", exclude="untimed"
-        )
+        add_timing_middleware(self, record=self.logger.info, prefix="app", exclude="untimed")
 
     def configure_gzip_middleware(self) -> None:
         """Add Middleware GZip"""
